'                                        EXAMPLE02
'
'                HOW TO DECLARE A LOCAL VARIABLE AND CALL MORE THAN ONE PROCEDURE.
'*************************************************************************************************
'IMPORTANT: Please run or examine closely previous examples before running this code. If you do
'           this, you are more likely to understand this example.
'************************************************************************************************* 
'WHAT'S NEW IN THIS EXAMPLE:
'
'   LOCAL VARIABLES: This example demonstrates how to declare a local variable. A local variable
'                    is only known within the procedure in which it is declared.  Also, it is
'                    is only active while the code in that procedure is being run. 
'   TWO PROCEDURES:  This example demonstrates calling more than one procedure.
'*************************************************************************************************
'
'DIFFICULTY LEVEL: Very easy
'
'PURPOSE:
'  -- The purpose of this example is to demonstrates how to declare a local variable
'     within a procedure, and to demonstrate how to call two procedures. One procedure, when
'     called, will cause the LED at port A16 to blink five times. This will be followed by a call
'     to a second procedure that will cause the LED at port A17 to blink five times.
'
'  -- Note that one sequence of five blinks is followed in time by another sequence of five blinks.
'     This sequential behavior occurs because only one processor is executing the code. In the next
'     example, EXAMPLE03, both sequences of blinks will occur at the SAME TIME because we will use
'     two processors.  One processor will handle one sequence of five blinks and at the same
'     time a second processor will handle a second sequence of five blinks.
'
'ADDITIONAL INFORMATION: 
'  -- The comments in the code are typically used to explain new statements or new concepts not
'     explained in previous examples.  In order to eliminate comment clutter, the code comments
'     in previous examples have usually been eliminated.
'  -- IT IS ASSUMED THAT THE PROGRAMMER HAS OR IS READING THE PROPELLER'S EXTERNAL DOCUMENTATION
'     AND HAS SOME PREVIOUS PROGRAMMING EXPERIENCE WITH MICROCONTROLLERS. IT IS FURTHER
'     ASSUMED THAT TWO LEDS ARE CONNECTED TO PORTS A16 AND A17.
'  -- Every effort has been made to insure that the code in all examples runs correctly.
'
'Submitted by Dave Scanlan, Feb 27, 2006           
'File: Example02_LocalVarAndCallingTwoProcedures.spin
'*************************************************************************************************
'CORRECT OUTPUT: The LED at port A16 will blink five times.  This sequence of blinks will be
'                followed by the LED at port A17 blinking five times.
'
'                NOTE: The output from this example will be compared to the output in the next
'                      example where two processors will be running.
'*************************************************************************************************
CON
  _clkmode  = xtal1 + pll16x
  _xinfreq  = 5_000_000
' 
  High = 1
  Low  = 0
  Out = %1
'
VAR
  'No global variables needed
' 
PUB Start
  BlinkingLED_A16                   'This call is executed first.
  BlinkingLED_A17                   'This call is executed next but only after       
                                    '   BlinkingLED_A16 has finished executing.    
'
PRI BlinkingLED_A16 | Pin           '| Pin is declared as a local variable
                                    '  Pin is only known within BlinkingLED_A16                                          
  Pin := 16                         '  Reference to Pin stops when this procedure ends.                 
  DirA[Pin] := Out
'                
  Repeat 5
   OutA[Pin] := High                'LED ON                               
   WaitCnt(40_000_000 + Cnt)        'ONE-HALF SECOND WAIT
   OutA[Pin] := Low                 'LED OFF
   WaitCnt(40_000_000 + Cnt)        'ONE-HALF SECOND WAIT
'
'
PRI BlinkingLED_A17 | Pin           '| Pin is declared as a local variable
                                    '  Pin is only known within BlinkingLED_A17.                                          
  Pin := 17                         '  Reference to Pin stops when this procedure ends.                 
  DirA[Pin] := Out
'                
  Repeat 5
    OutA[Pin] := High               'LED ON                               
    WaitCnt(40_000_000 + Cnt)       'ONE-HALF SECOND WAIT
    OutA[Pin] := Low                'LED OFF
    WaitCnt(40_000_000 + Cnt)       'ONE-HALF SECOND WAIT
'
'INDENTION IS IMPORTANT IN SPIN.