'                                           EXAMPLE07
'
'                           CHECKS FOR A HIGH ON PIN A1; HAS VIDEO OUTPUT                     
'**************************************************************************************
'IMPORTANT: This example requires an understanding of examples 01 and 03.
'**************************************************************************************
'WHAT'S NEW IN THIS EXAMPLE:
'
'   If-Else statement: This statement operates the same as If-Else statements in most
'                      other languages.  Be careful because Spin is indention sensitive.
'                      Note the indention in the code.
'
'   DirA[1] := In      Sets the direction of Pin A1 to Input. BE CAREFUL TO NOT EXCEED
'                      3.3 VOLTS.  (A maximum input voltage has not been established at
'                      this time.)
'
'   VideoDisplay.Out(3): This combination of statements will produce white on red.
'   VideoDisplay.Out(7)
'
'   Repeat statement: "Repeat" in this example is an infinite loop. This causes the program
'                     to constantly check for a High on Pin A1. You must indent
'                     properly for this to work as desired.
'**************************************************************************************
'DIFFICULTY LEVEL: Very Easy
'
'MAIN PURPOSE:
'  -- Demonstrates how to check for a High on an Input Pin.
'
'ADDITIONAL INFORMATION: 
'  -- The video signal output is a composite signal.
'  -- TV_Terminal is an object call TV_Terminal.spin found in the "Propeller Tool"
'     subdirectory.
'  -- Any name could have been used instead of "VideoDisplay"
'  -- This example assumes you have the development kit or a schematic of it.  
'     You will need one of these to generate a composite video out.
'  -- USE A 10K PULL-DOWN RESISTER TO KEEP PIN A1 FROM FLOATING: Place a 10K resistor
'     between Pin A1 and Vss.
'  -- This example only uses one Cog.
'
'Submitted by Dave Scanlan, March 8, 2006          
'File: Example07_ReadingAnInputPort.spin
'***********************************************************************************
'CORRECT OUTPUT: If Pin A1 is High the following happens:
'                  (1) The message "INPUT AT PIN A1" is repeatedly displayed on the
'                      monitor.
'                  (2) The monitor's foreground and background become white-on-blue.
'                  (3) The LED at A16 is turned on.
'
'                If Pin A1 is Low the following happens:
'                  (1) The message "NO INPUT" is repeatedly displayed on the monitor.
'                  (2) The monitor's foreground and background become white-on-red.
'                  (3) The LED at A16 is turned off.
'
'NOTE: USE A 10k PULL-DOWN RESISTER TO KEEP PIN A1 FROM FLOATING: Place a 10K resistor
'      betweein Pin A1 and Vss.
'**************************************************************************************
'
CON
  _clkmode = xtal1 + pll16x       
  _xinfreq = 5_000_000
  NewLine = 13
  High = 1
  Low = 0
  Out = %1
  In = %0
'
VAR
'  No gobal variables in this program
'  
OBJ
  VideoDisplay: "TV_Terminal"               'Creates the object VideoDisplay
'
PUB Start                                   'Any name will do here: Start, Begin, Main, etc.
  VideoDisplay.Start                        'Initializes the VideoDisplay object                                                
  CheckForInput
'  
PRI CheckForInput
'
  DirA[1]  := In                            'Sets Pin A1 to Input
  DirA[16] := Out                           'Sets Pin A16 to Output
'
  Repeat                                    'An infinite loop. Indention is important
' 
    If InA[1] == High                       'Be sure to indent under the If 
      SetScreenToWhiteOnDarkBlue
      VideoDisplay.str(String("INPUT AT PIN A1"))
      OutA[16] := High
    Else                                    'Be sure to indent under the Else
      SetScreenToWhiteOnRed
      VideoDisplay.str(String("NO INPUT"))
      OutA[16] := Low
'     
    VideoDisplay.out(NewLine)
'
PRI SetScreenToWhiteOnDarkBlue              'This combination of Out's sets the monitor 
  VideoDisplay.Out(3)                       ' to display white-on-blue
  VideoDisplay.Out(5)
'
PRI SetScreenToWhiteOnRed                   'This combination of Out's sets the monitor
  VideoDisplay.Out(3)                       ' to display white-on-red.
  VideoDisplay.Out(7)                         
'
'
'INDENTION IS IMPORTANT IN SPIN.
'