'                                   EXAMPLE 08
'
'                    DISPLAYS KEYBOARD CHARACTERS ON A VIDEO MONITOR                          
'****************************************************************************
'IMPORTANT: This example requires an understanding of example 04.
'****************************************************************************
'WHAT'S NEW IN THIS EXAMPLE:
'   Keyboard_iso: This is a Spin object that must be used in order to use
'                 GetKey and Present
'   GetKey: GetKey will return the code for any key pressed on the keyboard.
'           Using GetKey, you can display characters on a video monitor.
'   Present: Returns a TRUE if a keyboard is connected.
'****************************************************************************
'DIFFICULTY LEVEL: Very Easy
'
'MAIN PURPOSE:
'  -- Demonstrates how to interface the keyboard to the Propeller and how to
'     display a key press on a video monitor.
'
'ADDITIONAL INFORMATION:
'  -- A PS/2 keyboard must be properly connected to the Properller.
'  -- This example assumes you have the development kit or a schematic of it.     
'  -- This example only uses one Cog (processor).
'
'Submitted by Dave Scanlan, March 12, 2006         
'File: Example08_Keyboard input.spin
'****************************************************************************  
'CORRECT OUTPUT: Keyboard characters will be displayed on a video monitor.
'**************************************************************************** 
'
CON
  _clkmode = xtal1 + pll16x       
  _xinfreq = 5_000_000
  NewLine = 13
  PS2ToProperllerPins_Setup = 6  'See number(1) at the bottom.
  KeyLocks_Setup = %0_000_010    'CapsLock ON: See number(2) at the bottom.
' KeyLocks_Setup = %0_000_000    'CapsLock OFF: See number(2) at the bottom.
  AutoRepeat_Setup = %01_01000   'See number(3) at the bottom.
'
OBJ
  VideoDisplay: "TV_Terminal"
  KB : "Keyboard_iso"              'Creates an instance Keyboard_iso called KB
' 
PUB Start
'
  VideoDisplay.start
  SetScreenToWhiteOnDarkBlue
' KB.Startx(PS/2 pins setup, CapsLock ON, .5second delay and 15cps key repeat rate)
  KB.Startx(PS2ToProperllerPins_Setup, KeyLocks_Setup, AutoRepeat_Setup)
  WaitCnt(50_000_000 + Cnt)
' 
  If KB.Present                      'Present is true if a keyboard is connected
    VideoDisplay.str(string("KEYBOARD CONNECTED"))
    VideoDisplay.Out(NewLine)
    Repeat
      VideoDisplay.out(KB.GetKey)
  Else
    VideoDisplay.str(string("ERROR: KEYBOARD NOT CONNECTED"))
'
PRI SetScreenToWhiteOnDarkBlue                  
  VideoDisplay.out(3)                              
  VideoDisplay.out(5)
  
'ADDITIONAL INFORMATION:
'****************************************************************************   
'(1) 6 is a setup code that will properly match the pins on a PS/2 male 
'    conector with a PS/2 female connector that is connected to the
'    the Propeller.  See Keyboard_iso.spin for more pin setup codes.
'(2) %0_000_010 is a setup code that will set CapsLock ON (bit 1). See 
'    Keyboard_iso for more KeyLock setup settings, such as NumLock and
'    ScrollLock.
'(3) %01_01000 is a setup code that will produce a .5sec (bit 5) delay before
'    auto repeat starts and a 15cps repeat rate (bit 3). See Keyboard_iso
'    for more setup settings.
'****************************************************************************                                                   